==> data-hub-4.2.5-sources.jar: io/intino/datahub/graph/Terminal.java <==
package io.intino.datahub.graph;

import io.intino.datahub.graph.*;

public class Terminal  extends io.intino.magritte.framework.Layer implements io.intino.magritte.framework.tags.Terminal {
	protected io.intino.datahub.graph.Terminal.AllowsBpmIn allowsBpmIn;
	protected io.intino.datahub.graph.Terminal.Publish publish;
	protected io.intino.datahub.graph.Terminal.Subscribe subscribe;

	public Terminal(io.intino.magritte.framework.Node node) {
		super(node);
	}

	public io.intino.datahub.graph.Terminal.AllowsBpmIn allowsBpmIn() {
		return allowsBpmIn;
	}

	public io.intino.datahub.graph.Terminal.Publish publish() {
		return publish;
	}

	public io.intino.datahub.graph.Terminal.Subscribe subscribe() {
		return subscribe;
	}

	protected java.util.List<io.intino.magritte.framework.Node> componentList$() {
		java.util.Set<io.intino.magritte.framework.Node> components = new java.util.LinkedHashSet<>(super.componentList$());
		if (allowsBpmIn != null) components.add(this.allowsBpmIn.core$());
		if (publish != null) components.add(this.publish.core$());
		if (subscribe != null) components.add(this.subscribe.core$());
		return new java.util.ArrayList<>(components);
	}

	@Override
	protected java.util.Map<java.lang.String, java.util.List<?>> variables$() {
		java.util.Map<String, java.util.List<?>> map = new java.util.LinkedHashMap<>();
		return map;
	}

	@Override
	protected void addNode$(io.intino.magritte.framework.Node node) {
		super.addNode$(node);
		if (node.is("Terminal$AllowsBpmIn")) this.allowsBpmIn = node.as(io.intino.datahub.graph.Terminal.AllowsBpmIn.class);
		if (node.is("Terminal$Publish")) this.publish = node.as(io.intino.datahub.graph.Terminal.Publish.class);
		if (node.is("Terminal$Subscribe")) this.subscribe = node.as(io.intino.datahub.graph.Terminal.Subscribe.class);
	}

	@Override
	    protected void removeNode$(io.intino.magritte.framework.Node node) {
	        super.removeNode$(node);
	        if (node.is("Terminal$AllowsBpmIn")) this.allowsBpmIn = null;
	        if (node.is("Terminal$Publish")) this.publish = null;
	        if (node.is("Terminal$Subscribe")) this.subscribe = null;
	    }

	@Override
	protected void load$(java.lang.String name, java.util.List<?> values) {
		super.load$(name, values);
	}

	@Override
	protected void set$(java.lang.String name, java.util.List<?> values) {
		super.set$(name, values);
	}

	public Create create() {
		return new Create(null);
	}

	public Create create(java.lang.String name) {
		return new Create(name);
	}

	public class Create  {
		protected final java.lang.String name;

		public Create(java.lang.String name) {
			this.name = name;
		}

		public io.intino.datahub.graph.Terminal.AllowsBpmIn allowsBpmIn(io.intino.datahub.graph.Datalake.Context context) {
		    io.intino.datahub.graph.Terminal.AllowsBpmIn newElement = core$().graph().concept(io.intino.datahub.graph.Terminal.AllowsBpmIn.class).createNode(this.name, core$()).as(io.intino.datahub.graph.Terminal.AllowsBpmIn.class);
			newElement.core$().set(newElement, "context", java.util.Collections.singletonList(context));
		    return newElement;
		}

		public io.intino.datahub.graph.Terminal.Publish publish(java.util.List<io.intino.datahub.graph.Datalake.Tank.Event> tanks) {
		    io.intino.datahub.graph.Terminal.Publish newElement = core$().graph().concept(io.intino.datahub.graph.Terminal.Publish.class).createNode(this.name, core$()).as(io.intino.datahub.graph.Terminal.Publish.class);
			newElement.core$().set(newElement, "tanks", tanks);
		    return newElement;
		}

		public io.intino.datahub.graph.Terminal.Subscribe subscribe(java.util.List<io.intino.datahub.graph.Datalake.Tank.Event> tanks) {
		    io.intino.datahub.graph.Terminal.Subscribe newElement = core$().graph().concept(io.intino.datahub.graph.Terminal.Subscribe.class).createNode(this.name, core$()).as(io.intino.datahub.graph.Terminal.Subscribe.class);
			newElement.core$().set(newElement, "tanks", tanks);
		    return newElement;
		}

	}

	public static class AllowsBpmIn  extends io.intino.magritte.framework.Layer implements io.intino.magritte.framework.tags.Terminal {
		protected java.lang.String processStatusClass;
		protected io.intino.datahub.graph.Datalake.Context context;

		public AllowsBpmIn(io.intino.magritte.framework.Node node) {
			super(node);
		}

		public java.lang.String processStatusClass() {
			return processStatusClass;
		}

		public io.intino.datahub.graph.Datalake.Context context() {
			return context;
		}

		public AllowsBpmIn processStatusClass(java.lang.String value) {
			this.processStatusClass = value;
			return (AllowsBpmIn) this;
		}

		public AllowsBpmIn context(io.intino.datahub.graph.Datalake.Context value) {
			this.context = value;
			return (AllowsBpmIn) this;
		}

		@Override
		protected java.util.Map<java.lang.String, java.util.List<?>> variables$() {
			java.util.Map<String, java.util.List<?>> map = new java.util.LinkedHashMap<>();
			map.put("processStatusClass", new java.util.ArrayList(java.util.Collections.singletonList(this.processStatusClass)));
			map.put("context", this.context != null ? new java.util.ArrayList(java.util.Collections.singletonList(this.context)) : java.util.Collections.emptyList());
			return map;
		}

		@Override
		protected void load$(java.lang.String name, java.util.List<?> values) {
			super.load$(name, values);
			if (name.equalsIgnoreCase("processStatusClass")) this.processStatusClass = io.intino.magritte.framework.loaders.StringLoader.load(values, this).get(0);
			else if (name.equalsIgnoreCase("context")) this.context = io.intino.magritte.framework.loaders.NodeLoader.load(values, io.intino.datahub.graph.Datalake.Context.class, this).get(0);
		}

		@Override
		protected void set$(java.lang.String name, java.util.List<?> values) {
			super.set$(name, values);
			if (name.equalsIgnoreCase("processStatusClass")) this.processStatusClass = (java.lang.String) values.get(0);
			else if (name.equalsIgnoreCase("context")) this.context = values.get(0)!= null ? core$().graph().load(((io.intino.magritte.framework.Layer) values.get(0)).core$().id()).as(io.intino.datahub.graph.Datalake.Context.class) : null;
		}

		public io.intino.datahub.graph.NessGraph graph() {
			return (io.intino.datahub.graph.NessGraph) core$().graph().as(io.intino.datahub.graph.NessGraph.class);
		}
	}

	public static class Publish  extends io.intino.magritte.framework.Layer implements io.intino.magritte.framework.tags.Terminal {
		protected java.util.List<io.intino.datahub.graph.Datalake.Tank.Event> tanks = new java.util.ArrayList<>();

		public Publish(io.intino.magritte.framework.Node node) {
			super(node);
		}

		public java.util.List<io.intino.datahub.graph.Datalake.Tank.Event> tanks() {
			return tanks;
		}

		public io.intino.datahub.graph.Datalake.Tank.Event tanks(int index) {
			return tanks.get(index);
		}

		public java.util.List<io.intino.datahub.graph.Datalake.Tank.Event> tanks(java.util.function.Predicate<io.intino.datahub.graph.Datalake.Tank.Event> predicate) {
			return tanks().stream().filter(predicate).collect(java.util.stream.Collectors.toList());
		}

		@Override
		protected java.util.Map<java.lang.String, java.util.List<?>> variables$() {
			java.util.Map<String, java.util.List<?>> map = new java.util.LinkedHashMap<>();
			map.put("tanks", this.tanks);
			return map;
		}

		@Override
		protected void load$(java.lang.String name, java.util.List<?> values) {
			super.load$(name, values);
			if (name.equalsIgnoreCase("tanks")) this.tanks = io.intino.magritte.framework.loaders.NodeLoader.load(values,  io.intino.datahub.graph.Datalake.Tank.Event.class, this);
		}

		@Override
		protected void set$(java.lang.String name, java.util.List<?> values) {
			super.set$(name, values);
			if (name.equalsIgnoreCase("tanks")) this.tanks = ((java.util.List<java.lang.Object>) values).stream().
				map(s -> graph().core$().load(((io.intino.magritte.framework.Layer) s).core$().id()).as(io.intino.datahub.graph.Datalake.Tank.Event.class)).collect(java.util.stream.Collectors.toList());
		}

		public io.intino.datahub.graph.NessGraph graph() {
			return (io.intino.datahub.graph.NessGraph) core$().graph().as(io.intino.datahub.graph.NessGraph.class);
		}
	}

	public static class Subscribe  extends io.intino.magritte.framework.Layer implements io.intino.magritte.framework.tags.Terminal {
		protected java.util.List<io.intino.datahub.graph.Datalake.Tank.Event> tanks = new java.util.ArrayList<>();

		public Subscribe(io.intino.magritte.framework.Node node) {
			super(node);
		}

		public java.util.List<io.intino.datahub.graph.Datalake.Tank.Event> tanks() {
			return tanks;
		}

		public io.intino.datahub.graph.Datalake.Tank.Event tanks(int index) {
			return tanks.get(index);
		}

		public java.util.List<io.intino.datahub.graph.Datalake.Tank.Event> tanks(java.util.function.Predicate<io.intino.datahub.graph.Datalake.Tank.Event> predicate) {
			return tanks().stream().filter(predicate).collect(java.util.stream.Collectors.toList());
		}

		@Override
		protected java.util.Map<java.lang.String, java.util.List<?>> variables$() {
			java.util.Map<String, java.util.List<?>> map = new java.util.LinkedHashMap<>();
			map.put("tanks", this.tanks);
			return map;
		}

		@Override
		protected void load$(java.lang.String name, java.util.List<?> values) {
			super.load$(name, values);
			if (name.equalsIgnoreCase("tanks")) this.tanks = io.intino.magritte.framework.loaders.NodeLoader.load(values,  io.intino.datahub.graph.Datalake.Tank.Event.class, this);
		}

		@Override
		protected void set$(java.lang.String name, java.util.List<?> values) {
			super.set$(name, values);
			if (name.equalsIgnoreCase("tanks")) this.tanks = ((java.util.List<java.lang.Object>) values).stream().
				map(s -> graph().core$().load(((io.intino.magritte.framework.Layer) s).core$().id()).as(io.intino.datahub.graph.Datalake.Tank.Event.class)).collect(java.util.stream.Collectors.toList());
		}

		public io.intino.datahub.graph.NessGraph graph() {
			return (io.intino.datahub.graph.NessGraph) core$().graph().as(io.intino.datahub.graph.NessGraph.class);
		}
	}


	public io.intino.datahub.graph.NessGraph graph() {
		return (io.intino.datahub.graph.NessGraph) core$().graph().as(io.intino.datahub.graph.NessGraph.class);
	}
}

==> data-hub-5.6.2-sources.jar: io/intino/datahub/graph/Terminal.java <==
package io.intino.datahub.graph;

import io.intino.datahub.graph.*;

public class Terminal  extends io.intino.magritte.framework.Layer implements io.intino.magritte.framework.tags.Terminal {
	protected io.intino.datahub.graph.Terminal.Bpm bpm;
	protected io.intino.datahub.graph.Terminal.Publish publish;
	protected io.intino.datahub.graph.Terminal.Subscribe subscribe;

	public Terminal(io.intino.magritte.framework.Node node) {
		super(node);
	}

	public io.intino.datahub.graph.Terminal.Bpm bpm() {
		return bpm;
	}

	public io.intino.datahub.graph.Terminal.Publish publish() {
		return publish;
	}

	public io.intino.datahub.graph.Terminal.Subscribe subscribe() {
		return subscribe;
	}

	protected java.util.List<io.intino.magritte.framework.Node> componentList$() {
		java.util.Set<io.intino.magritte.framework.Node> components = new java.util.LinkedHashSet<>(super.componentList$());
		if (bpm != null) components.add(this.bpm.core$());
		if (publish != null) components.add(this.publish.core$());
		if (subscribe != null) components.add(this.subscribe.core$());
		return new java.util.ArrayList<>(components);
	}

	@Override
	protected java.util.Map<java.lang.String, java.util.List<?>> variables$() {
		java.util.Map<String, java.util.List<?>> map = new java.util.LinkedHashMap<>();
		return map;
	}

	@Override
	protected void addNode$(io.intino.magritte.framework.Node node) {
		super.addNode$(node);
		if (node.is("Terminal$Bpm")) this.bpm = node.as(io.intino.datahub.graph.Terminal.Bpm.class);
		if (node.is("Terminal$Publish")) this.publish = node.as(io.intino.datahub.graph.Terminal.Publish.class);
		if (node.is("Terminal$Subscribe")) this.subscribe = node.as(io.intino.datahub.graph.Terminal.Subscribe.class);
	}

	@Override
	    protected void removeNode$(io.intino.magritte.framework.Node node) {
	        super.removeNode$(node);
	        if (node.is("Terminal$Bpm")) this.bpm = null;
	        if (node.is("Terminal$Publish")) this.publish = null;
	        if (node.is("Terminal$Subscribe")) this.subscribe = null;
	    }

	@Override
	protected void load$(java.lang.String name, java.util.List<?> values) {
		super.load$(name, values);
	}

	@Override
	protected void set$(java.lang.String name, java.util.List<?> values) {
		super.set$(name, values);
	}

	public Create create() {
		return new Create(null);
	}

	public Create create(java.lang.String name) {
		return new Create(name);
	}

	public class Create  {
		protected final java.lang.String name;

		public Create(java.lang.String name) {
			this.name = name;
		}

		public io.intino.datahub.graph.Terminal.Bpm bpm(io.intino.datahub.graph.Datalake.Split split) {
		    io.intino.datahub.graph.Terminal.Bpm newElement = core$().graph().concept(io.intino.datahub.graph.Terminal.Bpm.class).createNode(this.name, core$()).as(io.intino.datahub.graph.Terminal.Bpm.class);
			newElement.core$().set(newElement, "split", java.util.Collections.singletonList(split));
		    return newElement;
		}

		public io.intino.datahub.graph.Terminal.Publish publish(java.util.List<io.intino.datahub.graph.Datalake.Tank.Event> tanks) {
		    io.intino.datahub.graph.Terminal.Publish newElement = core$().graph().concept(io.intino.datahub.graph.Terminal.Publish.class).createNode(this.name, core$()).as(io.intino.datahub.graph.Terminal.Publish.class);
			newElement.core$().set(newElement, "tanks", tanks);
		    return newElement;
		}

		public io.intino.datahub.graph.Terminal.Subscribe subscribe(java.util.List<io.intino.datahub.graph.Datalake.Tank.Event> tanks) {
		    io.intino.datahub.graph.Terminal.Subscribe newElement = core$().graph().concept(io.intino.datahub.graph.Terminal.Subscribe.class).createNode(this.name, core$()).as(io.intino.datahub.graph.Terminal.Subscribe.class);
			newElement.core$().set(newElement, "tanks", tanks);
		    return newElement;
		}

	}

	public static class Bpm  extends io.intino.magritte.framework.Layer implements io.intino.magritte.framework.tags.Terminal {
		protected java.lang.String processStatusClass;
		protected io.intino.datahub.graph.Datalake.Split split;

		public Bpm(io.intino.magritte.framework.Node node) {
			super(node);
		}

		public java.lang.String processStatusClass() {
			return processStatusClass;
		}

		public io.intino.datahub.graph.Datalake.Split split() {
			return split;
		}

		public Bpm processStatusClass(java.lang.String value) {
			this.processStatusClass = value;
			return (Bpm) this;
		}

		public Bpm split(io.intino.datahub.graph.Datalake.Split value) {
			this.split = value;
			return (Bpm) this;
		}

		@Override
		protected java.util.Map<java.lang.String, java.util.List<?>> variables$() {
			java.util.Map<String, java.util.List<?>> map = new java.util.LinkedHashMap<>();
			map.put("processStatusClass", new java.util.ArrayList(java.util.Collections.singletonList(this.processStatusClass)));
			map.put("split", this.split != null ? new java.util.ArrayList(java.util.Collections.singletonList(this.split)) : java.util.Collections.emptyList());
			return map;
		}

		@Override
		protected void load$(java.lang.String name, java.util.List<?> values) {
			super.load$(name, values);
			if (name.equalsIgnoreCase("processStatusClass")) this.processStatusClass = io.intino.magritte.framework.loaders.StringLoader.load(values, this).get(0);
			else if (name.equalsIgnoreCase("split")) this.split = io.intino.magritte.framework.loaders.NodeLoader.load(values, io.intino.datahub.graph.Datalake.Split.class, this).get(0);
		}

		@Override
		protected void set$(java.lang.String name, java.util.List<?> values) {
			super.set$(name, values);
			if (name.equalsIgnoreCase("processStatusClass")) this.processStatusClass = (java.lang.String) values.get(0);
			else if (name.equalsIgnoreCase("split")) this.split = values.get(0)!= null ? core$().graph().load(((io.intino.magritte.framework.Layer) values.get(0)).core$().id()).as(io.intino.datahub.graph.Datalake.Split.class) : null;
		}

		public io.intino.datahub.graph.NessGraph graph() {
			return (io.intino.datahub.graph.NessGraph) core$().graph().as(io.intino.datahub.graph.NessGraph.class);
		}
	}

	public static class Publish  extends io.intino.magritte.framework.Layer implements io.intino.magritte.framework.tags.Terminal {
		protected java.util.List<io.intino.datahub.graph.Datalake.Tank.Event> tanks = new java.util.ArrayList<>();

		public Publish(io.intino.magritte.framework.Node node) {
			super(node);
		}

		public java.util.List<io.intino.datahub.graph.Datalake.Tank.Event> tanks() {
			return tanks;
		}

		public io.intino.datahub.graph.Datalake.Tank.Event tanks(int index) {
			return tanks.get(index);
		}

		public java.util.List<io.intino.datahub.graph.Datalake.Tank.Event> tanks(java.util.function.Predicate<io.intino.datahub.graph.Datalake.Tank.Event> predicate) {
			return tanks().stream().filter(predicate).collect(java.util.stream.Collectors.toList());
		}

		@Override
		protected java.util.Map<java.lang.String, java.util.List<?>> variables$() {
			java.util.Map<String, java.util.List<?>> map = new java.util.LinkedHashMap<>();
			map.put("tanks", this.tanks);
			return map;
		}

		@Override
		protected void load$(java.lang.String name, java.util.List<?> values) {
			super.load$(name, values);
			if (name.equalsIgnoreCase("tanks")) this.tanks = io.intino.magritte.framework.loaders.NodeLoader.load(values,  io.intino.datahub.graph.Datalake.Tank.Event.class, this);
		}

		@Override
		protected void set$(java.lang.String name, java.util.List<?> values) {
			super.set$(name, values);
			if (name.equalsIgnoreCase("tanks")) this.tanks = ((java.util.List<java.lang.Object>) values).stream().
				map(s -> graph().core$().load(((io.intino.magritte.framework.Layer) s).core$().id()).as(io.intino.datahub.graph.Datalake.Tank.Event.class)).collect(java.util.stream.Collectors.toList());
		}

		public io.intino.datahub.graph.NessGraph graph() {
			return (io.intino.datahub.graph.NessGraph) core$().graph().as(io.intino.datahub.graph.NessGraph.class);
		}
	}

	public static class Subscribe  extends io.intino.magritte.framework.Layer implements io.intino.magritte.framework.tags.Terminal {
		protected java.util.List<io.intino.datahub.graph.Datalake.Tank.Event> tanks = new java.util.ArrayList<>();

		public Subscribe(io.intino.magritte.framework.Node node) {
			super(node);
		}

		public java.util.List<io.intino.datahub.graph.Datalake.Tank.Event> tanks() {
			return tanks;
		}

		public io.intino.datahub.graph.Datalake.Tank.Event tanks(int index) {
			return tanks.get(index);
		}

		public java.util.List<io.intino.datahub.graph.Datalake.Tank.Event> tanks(java.util.function.Predicate<io.intino.datahub.graph.Datalake.Tank.Event> predicate) {
			return tanks().stream().filter(predicate).collect(java.util.stream.Collectors.toList());
		}

		@Override
		protected java.util.Map<java.lang.String, java.util.List<?>> variables$() {
			java.util.Map<String, java.util.List<?>> map = new java.util.LinkedHashMap<>();
			map.put("tanks", this.tanks);
			return map;
		}

		@Override
		protected void load$(java.lang.String name, java.util.List<?> values) {
			super.load$(name, values);
			if (name.equalsIgnoreCase("tanks")) this.tanks = io.intino.magritte.framework.loaders.NodeLoader.load(values,  io.intino.datahub.graph.Datalake.Tank.Event.class, this);
		}

		@Override
		protected void set$(java.lang.String name, java.util.List<?> values) {
			super.set$(name, values);
			if (name.equalsIgnoreCase("tanks")) this.tanks = ((java.util.List<java.lang.Object>) values).stream().
				map(s -> graph().core$().load(((io.intino.magritte.framework.Layer) s).core$().id()).as(io.intino.datahub.graph.Datalake.Tank.Event.class)).collect(java.util.stream.Collectors.toList());
		}

		public io.intino.datahub.graph.NessGraph graph() {
			return (io.intino.datahub.graph.NessGraph) core$().graph().as(io.intino.datahub.graph.NessGraph.class);
		}
	}


	public io.intino.datahub.graph.NessGraph graph() {
		return (io.intino.datahub.graph.NessGraph) core$().graph().as(io.intino.datahub.graph.NessGraph.class);
	}
}
